@@ -1,6 +1,6 @@
 #!/usr/bin/perl -w
 
-# $Id: misc.pl,v 1.3 1999/08/08 15:16:58 root Exp $
+# $Id: misc.pl,v 1.4 1999/08/22 18:02:45 root Exp $
 
 # Copyright (c) Mark Summerfield 1999. All Rights Reserved.
 # May be used/distributed under the LGPL. 
@@ -32,14 +32,11 @@ sub abs_path {
 }
 
 
-# Based on the example in The Perl Cookbook, but doesn't commify the year in
-# dates, i.e. leave 20/7/2004 in tact.
+# Copied from The Perl Cookbook
 sub commify {
     my $num = reverse $_[0] ;
     $num =~ s/(\d\d\d)(?=\d)(?!\d*\.)/$1,/g ;
-    $num = scalar reverse $num ;
-    $num =~ s!(/\d),!$1!go ;
-    $num ;
+    scalar reverse $num ;
 }
 
 
